@@ -13,7 +13,7 @@ import os
 import warnings
 warnings.filterwarnings("ignore", category=SyntaxWarning)
 
-__version__ = "2.0.33"
+__version__ = "2.0.47"
 
 global_options = optparse.OptionParser(
     usage="yoc COMMAND [ARGS]"
@@ -97,6 +97,8 @@ def main():
         if sys.argv[1] == '-V' or sys.argv[1] == '--version':
             put_string(__version__)
             return
+        elif sys.argv[1] == '--help' or sys.argv[1] == '-h':
+            sys.argv[1] = 'help'
     cmd = YocCommand()
     cmd.Execute(sys.argv[1:])
 
