@@ -270,6 +270,13 @@ class Component:
         return True
 
     def variable_convert(self, varList, file_non_existent_no_err=False):
+        # include conditional compilation check
+        def include_conditional_compilation_check(inc):
+            v = inc.split('?')
+            if len(v) > 1:
+                filename = os.path.join(self.path, 'package.yaml')
+                put_string("The conditional compilation for include file is not supported! \n[%s] in File: %s " % (inc, filename), level="error")
+                exit(1)
         # script
         def script_filename_convert(root_path, script_file):
             script_filename = varList.convert(script_file)
@@ -282,6 +289,7 @@ class Component:
         # include
         incs = []
         for inc in self.build_config.include:
+            include_conditional_compilation_check(inc)
             inc = varList.convert(inc)
             if inc != None:
                 path = os.path.join(self.path, inc)
@@ -307,6 +315,7 @@ class Component:
         # internal_include
         internal_include = []
         for var in self.build_config.internal_include:
+            include_conditional_compilation_check(var)
             var = varList.convert(var)
             if var != None:
                 path = os.path.join(self.path, var)
