@@ -23,7 +23,7 @@ class HardwareInfo:
 
         for k, v in dic.items():
             if k in ['cpu_id', 'cpu_name', 'arch_name', 'chip_name', 'vendor_name', 'board_name',
-                     'ld_script', 'flash_program', 'toolchain_prefix'] and v:
+                     'ld_script', 'flash_program', 'toolchain_prefix', 'toolchain_path'] and v:
                 self.__dict__[k] = v
             else:
                 if type(v) == dict:
@@ -47,6 +47,7 @@ class HardwareInfo:
         self.ld_script = ''
         self.flash_program = ''
         self.toolchain_prefix = ''
+        self.toolchain_path = ''
 
         self.cpu_list = {}
 
@@ -105,7 +106,7 @@ class HardwareInfo:
                     for k, v in cpu.items():
                         text += '    {}: {}\n'.format(k, v)
         else:
-            for k in ['cpu_id', 'arch_name', 'vendor_name', 'chip_name', 'cpu_name', 'board_name', 'ld_script', 'toolchain_prefix']:
+            for k in ['cpu_id', 'arch_name', 'vendor_name', 'chip_name', 'cpu_name', 'board_name', 'ld_script', 'toolchain_prefix', 'toolchain_path']:
                 if self.__dict__[k]:
                     text += '  {}: {}\n'.format(k, self.__dict__[k])
 
@@ -123,16 +124,19 @@ class HardwareInfo:
 #   ld_script: configs/gcc_eflash.ld       # <可选项> 连接时使用 LD 脚本，当选把未设置时，使用对应的 board 的 LD 脚本
 #   flash_program: bin/flash_program.elf   # <可选项> 芯片全局烧写程序
 #   toolchain_prefix: csky-abiv2-elf       # <可选项> 编译器前缀
+#   toolchain_path: /home/xxx/csky-abiv2-elf/bin  # <可选项> 编译器的绝对路径
 #   cpu0:
 #     cpu_name: CK804EF                    # <必选项> 该芯片使用的 CPU 型号
 #     ld_script: configs/gcc_eflash.ld     # <必选项> 连接时使用 LD 脚本
 #     flash_program: bin/flash_program.elf # <可选项> 该CPU对应烧写程序，未指定时使用全局烧写程序
 #     toolchain_prefix: csky-abiv2-elf     # <可选项> 编译器前缀
+#     toolchain_path: /home/xxx/csky-abiv2-elf/bin  # <可选项> 编译器的绝对路径
 #   cpu1:
 #     cpu_name: CK804EF                    # <必选项> 该芯片使用的 CPU 型号
 #     ld_script: configs/gcc_eflash.ld     # <可选项> 连接时使用 LD 脚本
 #     flash_program: bin/flash_program.elf # <可选项> 该CPU对应烧写程序，未指定时使用全局烧写程序
 #     toolchain_prefix: csky-abiv2-elf     # <可选项> 编译器前缀
+#     toolchain_path: /home/xxx/csky-abiv2-elf/bin  # <可选项> 编译器的绝对路径
 '''
         if hw_key == 'solution':
             text_head = '''
@@ -160,6 +164,7 @@ class HardwareInfo:
 #   cpu_name: CK804EF
 #   ld_script: configs/gcc_eflash.ld
 #   toolchain_prefix: csky-abiv2-elf
+#   toolchain_path: /home/xxx/csky-abiv2-elf/bin
 #   flash_program: bin/flash_program.elf
 
 ## chip component(多处理器)
@@ -169,11 +174,13 @@ class HardwareInfo:
 #     ld_script: configs/gcc_eflash.ld     # <必选项> 连接时使用 LD 脚本
 #     flash_program: bin/flash_program.elf # <可选项> 该CPU对应烧写程序，未指定时使用全局烧写程序
 #     toolchain_prefix: csky-abiv2-elf     # <可选项> 编译器前缀
+#     toolchain_path: /home/xxx/csky-abiv2-elf/bin  # <可选项> 编译器的绝对路径
 #   cpu1:
 #     cpu_name: CK804EF                    # <必选项> 该芯片使用的 CPU 型号
 #     ld_script: configs/gcc_eflash.ld     # <必选项> 连接时使用 LD 脚本
 #     flash_program: bin/flash_program.elf # <可选项> 该CPU对应烧写程序，未指定时使用全局烧写程序
 #     toolchain_prefix: csky-abiv2-elf     # <可选项> 编译器前缀
+#     toolchain_path: /home/xxx/csky-abiv2-elf/bin  # <可选项> 编译器的绝对路径
 '''
 
         if text:
@@ -195,6 +202,8 @@ class build_config:
         self.ldflag = ''
         self.define = []
         self.linktype = ''
+        self.prebuild_script = ''
+        self.postbuild_script = ''
 
         for k, v in dic.items():
             if v:
@@ -202,7 +211,7 @@ class build_config:
 
     def out(self):
         text = ''
-        for k in ['cflag', 'cxxflag', 'asmflag', 'ldflag', 'linktype']:
+        for k in ['cflag', 'cxxflag', 'asmflag', 'ldflag', 'linktype', 'prebuild_script', 'postbuild_script']:
             value = self.__dict__[k]
             if value:
                 if len(value) < 60:
@@ -390,6 +399,8 @@ class Package(object):
 #     - yyy                                #   -lyyy
 #   libpath:                               # 指定静态库所在的路径（相对于该组件路径）
 #     - libs                               #   -Llibs
+#   prebuild_script: ''                    # 开始编译前需要执行的脚本文件(相对路径)
+#   postbuild_script: ''                   # 编译完成之后需要执行的脚本文件(相对路径)
 {build_config}
 # source_file:                             # <可选项> 指定参与编译的源代码文件，支持通配符，采用相对路径
 #   - src/*.c                              # 例：组件 src 目录下所有的扩展名为 c 的源代码文件
