@@ -14,11 +14,13 @@ import codecs
 
 from .tools import *
 
-qemu_csky_32 = ""
-qemu_csky_64 = "http://yoctools.oss-cn-beijing.aliyuncs.com/csky-qemu-x86_64-Ubuntu-16.04-20200901-1526.tar.gz"
+ck_rsicv_qemu_url = "http://yoctools.oss-cn-beijing.aliyuncs.com/xuantie-qemu-x86_64-Ubuntu-18.04-20220402-0353.tar.gz"
 
-qemu_rv_32 = ""
-qemu_rv_64 = "http://yoctools.oss-cn-beijing.aliyuncs.com/csky-qemu-x86_64-Ubuntu-16.04-20200901-1526.tar.gz"
+qemu_csky_32 = ck_rsicv_qemu_url
+qemu_csky_64 = ck_rsicv_qemu_url
+
+qemu_rv_32 = ck_rsicv_qemu_url
+qemu_rv_64 = ck_rsicv_qemu_url
 
 qemu_arm_32 = ""
 qemu_arm_64 = "http://yoctools.oss-cn-beijing.aliyuncs.com/qemu-arm-20200911.tar.gz"
@@ -147,7 +149,7 @@ class QemuYoC:
             bin_file = self.check_program()
         else:
             if verbose == 1:
-                put_string('warn: the toolchains was installed already, path = %s.' % bin_file, level='warning')
+                put_string('warn: the qemu was installed already, path = %s.' % bin_file, level='warning')
         return bin_file
 
     def which(self, cmd):
