@@ -443,9 +443,7 @@ def riscv_cpu_id(cpu):
         return 'rv32_16gpr'
     elif a == 'e906':
         return 'rv32_32gpr'
-    elif a == 'e907fp':
-        return 'rv32f_32gpr'
-    elif a == 'e906f':
+    elif a == 'e907fp' or a == 'e906f':
         return 'rv32f_32gpr'
     elif a == 'e906fd' or a == 'e907fd' or a == 'e907fdp':
         return 'rv32fd_32gpr'
