@@ -117,6 +117,9 @@ class CCT:
     def write(self, data):
         return self._port.write(data)
 
+    def reset_input_buffer(self):
+        self._port.reset_input_buffer()
+
     def check_sum(self, data_buf, length):
         cksum = 0
         count = 0
@@ -161,7 +164,7 @@ class CCT:
                     raise UnsupportedCommandError(self, '未知命令')
 
             if len(v) >= 4 and data[0] != cmd:
-                self.trace('command[0x%02x] response error.' % cmd)
+                self.trace('command[0x%02x],but[0x%02x] response error.' % (cmd, data[0]))
                 return False, [], None
                 # raise UnsupportedCommandError(self, cmd)
         finally:
@@ -179,7 +182,7 @@ class CCT:
             if now_tick - start_ticks > timeout:
                 break
 
-            ret, v, _ = self.command(CMD_CONNECT, 0xEF, struct.pack('!BBBB', 0x43, 0x53, 0x4B, 0x59), timeout=0.1)
+            ret, v, _ = self.command(CMD_CONNECT, 0xEF, struct.pack('!BBBB', 0x43, 0x53, 0x4B, 0x59), timeout=0.01)
             if ret and v[1] == 1:
                 if print_count != 0:
                     print()
@@ -190,7 +193,8 @@ class CCT:
                 if print_count == 0:
                     print("Wait ", end='')
                 else:
-                    print(".", end='')
+                    if print_count % 10 == 0:
+                        print(".", end='')
                 print_count += 1
                 sys.stdout.flush()
 
@@ -540,6 +544,8 @@ cct write <type> <id> <offset> <filename>
             cct.timeout = opt.timeout
         if not cct.connect():
             return
+        time.sleep(0.05)
+        cct.reset_input_buffer()
         ver = cct.get_version()
         if not ver:
             print("Get version error.")
