@@ -28,12 +28,12 @@ Export component to dest directory
         destPath = args[-1]
  
         if yoc.conf.yoc_path == os.path.abspath(destPath):
-            put_string("Can't export to the same path.")
+            put_string("Can't export to the same path.", level='error')
             return
 
         for c in componentList:
             if not yoc.components.get(c):
-                put_string("There is no component:%s found in workspace." % c)
+                put_string("There is no component:%s found in workspace." % c, level='warning')
         count = 0
         for component in yoc.components:
             if component.name in componentList:
@@ -49,7 +49,7 @@ Export component to dest directory
 
 
     def component_export(self, component, path):
-        if component.type in ['common', 'chip', 'sdk', 'sdk_chip']:
+        if component.type in ['common', 'chip', 'sdk']:
             p = 'components'
         elif component.type == 'board':
             p = 'boards'
@@ -63,5 +63,5 @@ Export component to dest directory
                     shutil.rmtree(dest)
                 shutil.copytree(component.path, dest)
             except Exception as ex:
-                put_string(str(ex))
+                put_string(str(ex), level='error')
                 pass
