@@ -17,6 +17,10 @@ class Tag(Command):
     helpDescription = """
 View current component tags
 """
+    def _Options(self, p):
+        p.add_option('-l', '--latest',
+                     dest='latest', action='store_true',
+                     help='Fetch the latest tag.')
 
     def Execute(self, opt, args):
         yoc = YoC()
@@ -34,7 +38,19 @@ View current component tags
         for component in components:
             git = GitRepo(component.path, component.repo_url)
             tags = git.GetRemoteTags()
-            if len(tags) > 0:
-                put_string(component.name + ':')
-                for b in tags:
-                    put_string('  %s' % b)
+            if opt.latest:
+                put_string(component.name + ':', color='orange')
+                if len(tags) > 0:
+                    last = "v0.0.0"
+                    for tag in tags:
+                        t = tag.name
+                        if t.startswith('v') and not re.search("\.{2,10}", t[1:]) and re.search("^\d+(\.\d+){0,10}$", t[1]):
+                            last = get_max_version(last, t)
+                    put_string(" - %s" % last)
+                else:
+                    put_string(' - NULL')
+            else:
+                if len(tags) > 0:
+                    put_string(component.name + ':')
+                    for b in tags:
+                        put_string('  %s' % b)
\ No newline at end of file
