@@ -4,6 +4,7 @@
 
 
 from __future__ import print_function
+import errno
 
 import os
 import stat
@@ -42,8 +43,11 @@ class ToolchainYoC:
 
     def download(self, arch):
         toolchain_path = os.path.join(self.basepath, arch)
-
-        if os.path.exists(toolchain_path) or arch not in all_toolchain_url:
+        if os.path.exists(toolchain_path):
+            put_string("Please delete %s first.", toolchain_path, level='error')
+            return
+        if arch not in all_toolchain_url:
+            put_string("Can't find %s from server.", arch, level='error')
             return
 
         architecture = platform.architecture()
@@ -81,7 +85,7 @@ class ToolchainYoC:
             self.link_bin(toolchain_path)
         else:
             self.update_env(arch)
-        put_string("Congratulations!")
+        put_string("Congratulations! Install the toolchains at `%s`" % toolchain_path)
 
     def link_bin(self, toolchain_path):
         toolchain_bin = os.path.join(toolchain_path, 'bin')
@@ -91,16 +95,18 @@ class ToolchainYoC:
             p = os.path.join(toolchain_bin, fil)
             if os.path.isfile(p):
                 if os.stat(p).st_mode & (stat.S_IXUSR | stat.S_IXGRP | stat.S_IXOTH) != 0:
+                    linkname = os.path.join('/usr/bin', os.path.basename(p))
                     try:
-                        os.symlink(p, os.path.join(
-                            '/usr/bin', os.path.basename(p)))
-                    except FileExistsError:
-                        pass
-                    except PermissionError:
-                        put_string("Please use: sudo", ' '.join(sys.argv), level='error')
-                        exit(-1)
-                    except Exception as e:
-                        pass
+                        os.symlink(p, linkname)
+                    except OSError as e:
+                        if e.errno == errno.EEXIST:
+                            os.remove(linkname)
+                            os.symlink(p, linkname)
+                        elif e.errno == errno.EPERM:
+                            put_string("Please use: sudo", ' '.join(sys.argv), level='error')
+                            exit(-1)
+                        else:
+                            pass
 
     def update_env(self, arch):
         toolchain_path = '$HOME/.thead/%s/bin' % arch
@@ -146,7 +152,10 @@ class ToolchainYoC:
             bin_file = self.check_program(arch)
         else:
             if verbose == 1:
-                put_string('warn: the toolchains was installed already, path = %s.' % bin_file, level='warning')
+                if os.getuid() == 0:
+                    put_string('warn: the toolchains was installed already, link bin file at %s, path = %s.' % (bin_file, os.path.join(self.basepath, arch)), level='warning')
+                else:
+                    put_string('warn: the toolchains was installed already, path = %s.' % bin_file, level='warning')
         return bin_file
 
     def which(self, cmd):
