@@ -12,6 +12,7 @@ import zipfile
 import codecs
 import json
 import re
+import shutil
 
 try:
     from urlparse import urlparse
@@ -25,12 +26,9 @@ except:
     import http.client as http
     urlretrieve = urllib.request.urlretrieve
 
-
-try:
-    import yaml
-except:
-    put_string("\n\nNot found pyyaml, please install: \nsudo pip install pyyaml", level='error')
-    sys.exit(0)
+from ruamel.yaml import YAML
+from ruamel.yaml.constructor import SafeConstructor
+from ruamel.yaml.constructor import ConstructorError
 
 class bcolors:
     BLACK = '\033[30m'
@@ -121,6 +119,66 @@ def latest_ver_get(ver1, ver2):
                 return ver2
             return ver2
 
+# s1 and s2 startwith 'v'
+def get_max_version(s1, s2):
+        max_version = 'v0.0.0'
+        if not s1.startswith('v') or not s2.startswith('v'):
+            return max_version
+        if s1 == s2:
+            max_version = s1
+            return max_version
+        s1 = s1[1:]
+        s2 = s2[1:]
+        s1bits = s1.split(".")
+        s2bits = s2.split(".")
+
+        if len(s1bits) >= len(s2bits):
+            amount = len(s1bits) - len(s2bits)
+            for i in range(amount):
+                s2bits.append("0")
+        else:
+            amount = len(s2bits) - len(s1bits)
+            for i in range(amount):
+                s1bits.append("0")
+
+        for i in range(len(s1bits)):
+            try:
+                if int(s1bits[i]) > int(s2bits[i]):
+                    max_version = s1
+                    break
+                elif int(s1bits[i]) < int(s2bits[i]):
+                    max_version = s2
+                    break
+                else:
+                    max_version = s2
+            except IndexError as err:
+                pass
+        max_version = 'v' + max_version
+        return max_version
+
+def del_files_under_dir(path, ignore=[]):
+    ls = os.listdir(path)
+    for i in ls:
+        if i in ignore:
+            continue
+        f_path = os.path.join(path, i)
+        if os.path.isdir(f_path):
+            shutil.rmtree(f_path)
+        else:
+            os.remove(f_path)
+
+def copy_files_under_dir(src_path, dst_path, ignore=[]):
+    if os.path.exists(src_path) and os.path.exists(dst_path):
+        ls = os.listdir(src_path)
+        for i in ls:
+            if i in ignore:
+                continue
+            f_path = os.path.join(src_path, i)
+            if os.path.isdir(f_path):
+                shutil.copytree(f_path, os.path.join(dst_path, i))
+            else:
+                shutil.copy2(f_path, dst_path)
+
 def string_len(text):
     L = 0
     R = ''
@@ -212,12 +270,30 @@ def color_print(text, key=[], end='\n', ignorecase=False):
         s = idx[v]
     print(text[s: len(text)], end=end)
 
+duplicatekey = []
+def construct_yaml_map(self, node, deep=True):
+    global duplicatekey
+    keys = set([])
+    for key_node, value_node in node.value:
+        key = self.construct_object(key_node, deep=deep)
+        if key in keys:
+            duplicatekey.append(key)
+        keys.add(key)
+    return SafeConstructor.construct_mapping(self, node, deep)
 
 def yaml_load(filename):
+    global duplicatekey
     try:
         with codecs.open(filename, 'r', encoding='UTF-8') as fh:
             text = fh.read()
-            return yaml.safe_load(text)
+            SafeConstructor.add_constructor(u'tag:yaml.org,2002:map', construct_yaml_map)
+            ryaml = YAML(typ='safe')
+            ryaml.allow_duplicate_keys = True
+            data = ryaml.load(text)
+            for em in duplicatekey:
+                put_string("Found duplicate key: (%s) in file: (%s), please check." % (em, filename), level='warning')
+            duplicatekey = []
+            return data
     except Exception as e:
         put_string("(%s) in file:%s" % (str(e), filename), level='error')
         exit(-1)
