@@ -231,7 +231,7 @@ class YoC:
                     depends_on.append(c)
         return depends_on
 
-    def getSolution(self, board_name=None, sdk_name=None, not_filter=False):
+    def getSolution(self, board_name=None, sdk_name=None, not_filter=False, file_non_existent_no_err=False):
         if board_name and sdk_name:
             put_string("Can't specify BOARD and SDK name at one time.", level='error')
             exit(-1)
@@ -308,13 +308,13 @@ class YoC:
                 if lost:
                     exit(-1)
                 components.add(component)
-                solution = Solution(components)
+                solution = Solution(components, file_non_existent_no_err)
 
                 return solution
 
-    def check_cmpt_download(self, name, update=True):
-        if self.components.get(name):
-            put_string("Component `%s` have installed already! Skip to install it!" % name, level='warning')
+    def check_cmpt_download(self, name, update=True, force=False):
+        if self.components.get(name) and not force:
+            put_string("Component `%s` have installed already! Skip to install it! You can add '-f' option to force installation." % name, level='warning')
         else:
             if update:
                 self.update()
